@@ -19,8 +19,15 @@
 
 """Provides the FocusTrackingPresenter for Orca."""
 
+__id__        = "$Id: focus_tracking_presenter.py,v 1.68 2006/06/10 00:54:47 wwalker Exp $"
+__version__   = "$Revision: 1.68 $"
+__date__      = "$Date: 2006/06/10 00:54:47 $"
+__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__license__   = "LGPL"
+
 import gobject
 import Queue
+#import threading
 import time
 
 import atspi
@@ -30,7 +37,7 @@ import orca
 import presentation_manager
 import settings
 import speech
-import threading
+import util
 
 from orca_i18n import _ # for gettext support
 
@@ -253,24 +260,30 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         deleting any scripts as necessary.
         """
 
-        apps = []
-
-        desktop = self.registry.desktop
-        for i in range(0, desktop.childCount):
-            try:
+        # Sometimes the desktop can become unavailable.  This happens
+        # often when synaptic is used to load new modules (see the bug
+        # report http://bugzilla.gnome.org/show_bug.cgi?id=342022).
+        # So...if this happens, we'll just move along.  The next
+        # successful call to _reclaimScripts will reclaim anything we
+        # didn't reclaim this time.
+        #
+        try:
+            apps = []
+            desktop = self.registry.desktop
+            for i in range(0, desktop.childCount):
                 acc = desktop.getChildAtIndex(i)
                 app = atspi.Accessible.makeAccessible(acc)
                 if app:
                     apps.insert(0, app)
-            except:
-                debug.printException(debug.LEVEL_FINEST)
 
-        for app in self._knownScripts.keys():
-            if apps.count(app) == 0:
-                script = self._knownScripts[app]
-                self._deregisterEventListeners(script)
-                del self._knownScripts[app]
-                del script
+            for app in self._knownScripts.keys():
+                if apps.count(app) == 0:
+                    script = self._knownScripts[app]
+                    self._deregisterEventListeners(script)
+                    del self._knownScripts[app]
+                    del script
+        except:
+            debug.printException(debug.LEVEL_FINEST)
 
     ########################################################################
     #                                                                      #
@@ -356,7 +369,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         try:
             self._processObjectEvent(event)
         except:
-            pass
+            debug.printException(debug.LEVEL_SEVERE)
 
         debug.println(debug.eventDebugLevel,
                       "^^^^^ PROCESS OBJECT EVENT %s ^^^^^\n" % event.type)
@@ -463,11 +476,11 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                 else:
                     debug.println(debug.LEVEL_WARNING,
                                   "  GIVING UP AFTER %d TRIES" \
-                                  % retryCount - 1)
+                                  % (retryCount - 1))
                     atspi.Accessible.deleteAccessible(event.source)
             except:
-                break
                 debug.printException(debug.LEVEL_WARNING)
+                break
 
     def processKeyboardEvent(self, keyboardEvent):
         """Processes the given keyboard event based on the keybinding from the
@@ -545,7 +558,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
         self._registerEventListener("window:deactivate")
         self._registerEventListener("object:children-changed:remove")
 
-        win = orca.findActiveWindow()
+        win = util.findActiveWindow()
         if win:
             # Generate a fake window activation event so the application
             # can tell the user about itself.
