@@ -18,10 +18,23 @@
 # Boston, MA 02111-1307, USA.
 
 """Provides support for defining keybindings and matching them to input
-events.
-"""
+events."""
 
-import gtk
+__id__        = "$Id: keybindings.py,v 1.7 2006/06/10 00:54:47 wwalker Exp $"
+__version__   = "$Revision: 1.7 $"
+__date__      = "$Date: 2006/06/10 00:54:47 $"
+__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__license__   = "LGPL"
+
+try:
+    # This can fail due to gtk not being available.  We want to
+    # be able to recover from that if possible.  The main driver
+    # for this is to allow "orca --text-setup" to work even if
+    # the desktop is not running.
+    #
+    import gtk
+except:
+    pass
 
 import atspi
 import debug
@@ -110,12 +123,12 @@ class KeyBindings:
         """Returns the input handler of the key binding that matches the
         given keycode and modifiers, or None if no match exists.
         """
-	handler = None
+        handler = None
         for keyBinding in self.keyBindings:
             if keyBinding.matches(keyboardEvent.hw_code, \
                                   keyboardEvent.modifiers):
                 handler = keyBinding.handler
-		break
+                break
         return handler
 
     def consumeKeyboardEvent(self, script, keyboardEvent):
