@@ -18,12 +18,23 @@
 # Boston, MA 02111-1307, USA.
 
 """Exposes a dictionary, keynames, that maps key events
-into localized words.
-"""
+into localized words."""
+
+__id__        = "$Id: keynames.py,v 1.5 2006/06/10 00:54:47 wwalker Exp $"
+__version__   = "$Revision: 1.5 $"
+__date__      = "$Date: 2006/06/10 00:54:47 $"
+__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__license__   = "LGPL"
 
 from orca_i18n import _ # for gettext support
 
 keynames = {}
 keynames["Shift_L"]      = _("left shift")
+keynames["Alt_L"]      = _("left alt")
+keynames["Control_L"]      = _("left control")
+keynames["Shift_L"]      = _("left shift")
+keynames["Alt_R"]      = _("right alt")
+keynames["Control_R"]      = _("right control")
 keynames["ISO_Left_Tab"] = _("left tab")
+keynames["SunF36"]       = _("F 11")
 keynames["SunF37"]       = _("F 12")
