@@ -19,8 +19,13 @@
 
 """Manages the settings for Orca.  This will defer to user settings first, but
 fallback to local settings if the user settings doesn't exist (e.g., in the
-case of gdm) or doesn't have the specified attribute.
-"""
+case of gdm) or doesn't have the specified attribute."""
+
+__id__        = "$Id: settings.py,v 1.54 2006/06/10 00:54:47 wwalker Exp $"
+__version__   = "$Revision: 1.54 $"
+__date__      = "$Date: 2006/06/10 00:54:47 $"
+__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__license__   = "LGPL"
 
 import re
 import sys
@@ -60,6 +65,7 @@ userCustomizableSettings = [
     "enableFunctionKeys",
     "enableActionKeys",
     "enableBraille",
+    "enableBrailleGrouping",
     "brailleVerbosityLevel",
     "brailleRolenameStyle",
     "enableBrailleMonitor",
@@ -124,6 +130,17 @@ verbalizePunctuationStyle = PUNCTUATION_STYLE_ALL
 #
 speechRateDelta         = 5
 
+# The absolue amount to change the speech pitch when
+# increasing or decreasing pitch.  This is a numerical
+# value that represents an ACSS pitch value.
+#
+speechPitchDelta        = 0.5
+
+# The port to listen on if orca is to act as a speech server for self
+# voicing applications.
+#
+speechServerPort        = 20433
+
 # If True, enable speech.
 #
 enableSpeech            = True
@@ -154,6 +171,12 @@ voices = {
 #
 enableBraille           = True
 
+# If True, enable the grouping of children on the braille display.
+# This is for things like displaying all items of a menu, tab list,
+# menu bar, etc., on a single line of the braille display.
+#
+enableBrailleGrouping   = False
+
 # If True, enable braille monitor.
 #
 enableBrailleMonitor    = False
@@ -277,6 +300,13 @@ brailleBindingsMap      = {}
 #
 cacheValues             = True
 
+# Script developer feature.  If False, no AT-SPI objects
+# will be cached locally.  Helps determine if there might be a
+# problem related to the cache being out of sync with the real
+# objects.
+#
+cacheAccessibles        = True
+
 # Assists with learn mode (what you enter when you press Insert+F1
 # and exit when you press escape.
 #
