@@ -18,10 +18,16 @@
 # Boston, MA 02111-1307, USA.
 
 """Utilities for obtaining speech utterances for objects.  In general,
-there probably should be a singleton instance of the SpeechUtil class.
-For those wishing to override the speech generators, however, one can
-create a new instance and replace/extend the speech generators as
-they see fit."""
+there probably should be a singleton instance of the SpeechGenerator
+class.  For those wishing to override the speech generators, however,
+one can create a new instance and replace/extend the speech generators
+as they see fit."""
+
+__id__        = "$Id: speechgenerator.py,v 1.61 2006/06/10 00:54:47 wwalker Exp $"
+__version__   = "$Revision: 1.61 $"
+__date__      = "$Date: 2006/06/10 00:54:47 $"
+__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__license__   = "LGPL"
 
 import math
 
@@ -153,7 +159,7 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken.
         """
 
-        result = atspi.getAcceleratorAndShortcut(obj)
+        result = util.getAcceleratorAndShortcut(obj)
 
         accelerator = result[0]
         #shortcut = result[1]
@@ -284,7 +290,7 @@ class SpeechGenerator:
 
         # Find all the unrelated labels in the dialog and speak them.
         #
-        labels = atspi.findUnrelatedLabels(obj)
+        labels = util.findUnrelatedLabels(obj)
         for label in labels:
             utterances.append(label.name)
 
@@ -542,8 +548,13 @@ class SpeechGenerator:
         Returns a list of utterances to be spoken for the object.
         """
 
-        #utterances = self._getDefaultSpeech(obj, already_focused)
-        utterances = self._getSpeechForAlert(obj, already_focused)
+        # [[[TODO: richb - readjusted to just get the default speech instead
+        # of treating the frame like an alert and speaking all unrelated
+        # labels. We'll need to see if this has any adverse effects and
+        # adjust accordingly.]]]
+        # 
+        utterances = self._getDefaultSpeech(obj, already_focused)
+        #utterances = self._getSpeechForAlert(obj, already_focused)
 
         self._debugGenerator("_getSpeechForFrame",
                              obj,
@@ -754,7 +765,7 @@ class SpeechGenerator:
                 utterances.append(obj.name)
         utterances.extend(self._getSpeechForObjectRole(obj))
 
-        [text, startOffset, endOffset] = atspi.getTextLineAtCaret(obj)
+        [text, startOffset, endOffset] = util.getTextLineAtCaret(obj)
         utterances.append(text)
 
         self._debugGenerator("_getSpeechForText",
@@ -1138,8 +1149,17 @@ class SpeechGenerator:
                     break
 
         if (len(utterances) == 0) and (not already_focused):
-            utterances.append(util.getDisplayedText(\
-                util.getRealActiveDescendant(obj)))
+            if settings.readTableCellRow:
+                parent = obj.parent
+                row = parent.table.getRowAtIndex(obj.index)
+                for i in range(0, parent.table.nColumns):
+                    accRow = parent.table.getAccessibleAt(row, i)
+                    cell = atspi.Accessible.makeAccessible(accRow)
+                    utterances.append(util.getDisplayedText(\
+                        util.getRealActiveDescendant(cell)))
+            else:
+                utterances.append(util.getDisplayedText(\
+                    util.getRealActiveDescendant(obj)))
 
         # [[[TODO: WDW - HACK attempt to determine if this is a node;
         # if so, describe its state.]]]
@@ -1228,7 +1248,7 @@ class SpeechGenerator:
         """
 
         title = None
-        frame = atspi.getFrame(obj)
+        frame = util.getFrame(obj)
         if frame:
             title = frame.name
         if not title:
